# Conceptual Data Layer Mapping from Collibra to SAP LeanIX
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#introduction)
  * [Configuring Synchronization of Conceptual Data Layer](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#configuring-synchronization-of-conceptual-data-layer)
  * [Choosing the Source Communities](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#choosing-the-source-communities)
  * [Matching Strategy](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#matching-strategy)
  * [Hierarchy and Naming](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#hierarchy-and-naming)
  * [Subtype of the Data Object](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#subtype-of-the-data-object)
  * [Filtering Assets by Type and Status](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#filtering-assets-by-type-and-status)
  * [Mapping Fields](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix#mapping-fields)


View all
Configure the mapping of the conceptual data layer from Collibra to the SAP LeanIX data object fact sheet, including assets, fields, responsibilities, and relations.
